@@ -1,13 +1,16 @@
 
-eval_prior_list <- function( par , par_prior )
+eval_prior_list <- function( par , par_prior, log = FALSE, eps=1E-50 )
 {
-	NP <- length(par_prior)
+	NP <- min( length(par), length(par_prior) )
 	prior_val <- rep(NA,NP)
 	for (pp in 1:NP){
 		# pp <- 1
 		pp_args <- as.list( par_prior[[pp]][[2]] )
 		pp_args[["x"]] <- par[pp]
 		prior_val[pp] <- do.call( what= par_prior[[pp]][[1]] , args = pp_args )
+		if (log){
+			prior_val[[pp]] <- log( prior_val[[pp]] + eps)
+		}						
 	}
 	return(prior_val)
 }
