@@ -1,5 +1,5 @@
 
-frm_define_model_R_function <- function(model)
+frm_define_model_R_function <- function(model, use_grad=2)
 {
 	R_fct <- NULL
 	R_args <- NULL
@@ -16,18 +16,21 @@ frm_define_model_R_function <- function(model)
 		R_fct <- logistic_regression 
 		R_fct_name <- "mdmb::logistic_regression"		
 		# R_args <- list("family"="binomial")
+		R_args <- list( "use_grad" = use_grad )
 		R_density_fct <- "frm_logistic_density"
 	}	
 	#--- linear regression with Box-Cox Transformation
 	if (model$model %in% c("bctreg") ){ 
-		R_fct <- bct_regression
+		R_fct <- bct_regression		
 		R_fct_name <- "mdmb::bct_regression"
+		R_args <- list( "use_grad" = use_grad )
 		R_density_fct <- "frm_mdmb_regression_density"
 	}	
 	#--- linear regression with Yeo-Johnson Transformation
 	if (model$model %in% c("yjtreg") ){ 
 		R_fct <- yjt_regression
 		R_fct_name <- "mdmb::yjt_regression"
+		R_args <- list( "use_grad" = use_grad )
 		R_density_fct <- "frm_mdmb_regression_density"
 	}			
 	#--- output
